@@ -19,28 +19,8 @@ import wandb
 import numpy as np
 import os
 
-import re
 
-
-class BasicCallback(Callback):
-    r"""
-    The basic callback that prepare hooks for step-based checkpoints.
-    Note: when inherit the basic class for new callbacks,
-    remember always call parent callback via super().
-    """
-
-    def __init__(self):
-        super(BasicCallback, self).__init__()
-
-    @rank_zero_only
-    def on_batch_end(self, trainer, pl_module):
-        super(BasicCallback, self).on_batch_end(trainer, pl_module)
-        # call step-based checkpoint.
-        if trainer.checkpoint_callback is not None:
-            trainer.checkpoint_callback.on_batch_end(trainer, pl_module)
-
-
-class ImageLoggingCallback(BasicCallback):
+class ImageLoggingCallback(Callback):
     r"""
     Callback for logging image.
     The callback is activate every period_batch step.
@@ -49,10 +29,8 @@ class ImageLoggingCallback(BasicCallback):
     def on_train_start(self, trainer, pl_module):
         super(ImageLoggingCallback, self).on_train_start(trainer, pl_module)
         # Setup loss log dict
-        if(not hasattr(self, 'logging_callback_inited')):
-            self.log_dict_name = 'log_image'
-            setattr(pl_module, self.log_dict_name, dict())
-            self.logging_callback_inited = True
+        self.log_dict_name = 'log_image'
+        setattr(pl_module, self.log_dict_name, dict())
 
     @rank_zero_only
     def on_batch_end(self, trainer, pl_module):
@@ -119,7 +97,7 @@ class EpochOrStepModelCheckpoint(ModelCheckpoint):
 
         self.step_last_check = None
 
-    def format_checkpoint_name(self, cnt, metrics, ver=None, epoch_or_step='epoch'):
+    def format_step_checkpoint_name(self, cnt, ver=None):
         """Generate a filename according to the defined template.
 
         Example::
@@ -139,22 +117,9 @@ class EpochOrStepModelCheckpoint(ModelCheckpoint):
             'missing=0.ckpt'
         """
         # check if user passed in keys to the string
-        groups = re.findall(r'(\{.*?)[:\}]', self.filename)
-
-        if (len(groups) == 0 or epoch_or_step == 'step'):
-            # default name
-            filename = f'{self.prefix}_ckpt_{epoch_or_step}_{cnt}'
-        else:
-            metrics[epoch_or_step] = cnt
-            filename = self.filename
-            for tmp in groups:
-                name = tmp[1:]
-                filename = filename.replace(tmp, name + '={' + name)
-                if name not in metrics:
-                    metrics[name] = 0
-            filename = filename.format(**metrics)
+        filename = f'{self.prefix}_ckpt_step_{cnt}'
         str_ver = f'_v{ver}' if ver is not None else ''
-        filepath = os.path.join(self.dirpath, self.prefix + filename + str_ver + '.ckpt')
+        filepath = os.path.join(self.dirpath, filename + str_ver + '.ckpt')
         return filepath
 
     @rank_zero_only
@@ -163,7 +128,6 @@ class EpochOrStepModelCheckpoint(ModelCheckpoint):
         if trainer.global_rank != 0:
             return
 
-        metrics = trainer.callback_metrics
         step = trainer.global_step
 
         if self.step_last_check is not None and (step - self.step_last_check) < self.period_step:
@@ -179,10 +143,10 @@ class EpochOrStepModelCheckpoint(ModelCheckpoint):
 
         self.step_last_check = step
 
-        filepath = self.format_checkpoint_name(step, metrics, epoch_or_step='step')
+        filepath = self.format_step_checkpoint_name(step)
         version_cnt = 0
         while os.path.isfile(filepath):
-            filepath = self.format_checkpoint_name(step, metrics, ver=version_cnt, epoch_or_step='step')
+            filepath = self.format_step_checkpoint_name(step, ver=version_cnt)
             # this step called before
             version_cnt += 1
 
